﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Net.Http;
using System.Web;

namespace WindowsFormsApplication1
{

    public partial class Form1 : Form
    {
        public int pointNo;

        public Form1()
        {
            InitializeComponent();
        }


        private void Form1_Load(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }


        private async void buttonExec_Click(object sender, EventArgs e)
        {
            // 結果をクリア
            textBoxStatus.Text = "";
            textBoxBody.Text = "";

            // URL実行
            try
            {
                HttpResponseMessage response = new HttpResponseMessage();

                using (HttpClient client = new HttpClient())
                {

                    TimeSpan timeout = new TimeSpan(0, 30, 0);      // Timeout 30分
                    client.Timeout = timeout;

                    // HeaderにX-ACT-Authorizationを設定
                    client.DefaultRequestHeaders.Add("X-ACT-Authorization", textBoxHeaders.Text);

                    response = await client.GetAsync(textBoxURL.Text);
                }

                textBoxStatus.Text = response.StatusCode.ToString();
                textBoxBody.Text = await response.Content.ReadAsStringAsync();
            }
            catch (Exception ex)
            {
                textBoxStatus.Text = "NG";
                if (ex.InnerException != null)
                {
                    textBoxBody.Text = ex.Message.ToString() + Environment.NewLine + ex.InnerException.ToString();
                }
                else
                {
                    textBoxBody.Text = ex.Message.ToString();
                }
            }

        }

        private void buttonReset_Click(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }


        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // App.configからURLを取得
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

            // 必須パラメータ
            if (textBoxUserName.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            if (textBoxPassword.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            // UserNameとPasswordからヘッダー作成
            // 「ユーザー名:パスワード」をBASE64エンコードしたものを値として表示
            string base64str = textBoxUserName.Text + ":" + textBoxPassword.Text;
            byte[] bs = System.Text.Encoding.UTF8.GetBytes(base64str);
            textBoxHeaders.Text = Convert.ToBase64String(bs);

            // 左8文字を取得 (例: 00000001)
            textBoxURL.Text += "?NWID=" + comboBoxNWID.Text.Substring(0, 8);

            // Point
            if (textBoxPoint1.Text.Length > 0)
            {
                textBoxURL.Text += "&Point1=" + textBoxPoint1.Text;
            }
            else
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }


            if (textBoxPoint2.Text.Length > 0)
            {
                // カンマで区切る
                string[] stArrayData = textBoxPoint2.Text.Split(',');

                // 初期化
                pointNo = 2;
                foreach (string stData in stArrayData)
                {
                    textBoxURL.Text += "&Point" + pointNo.ToString() + "=" + stData;
                    pointNo++;
                }
            }
            else
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            // オプション
            // 計算方向
            if (radioButtonCalcKindTime.Checked != false)
            {
                textBoxURL.Text += "&CalcKind=0";
            }
            else
            {
                textBoxURL.Text += "&CalcKind=1";
            }

            // 高速道路
            if (comboBoxNWID.Text.Substring(0,8) == "00f00108")
            {
                // 旅客のとき
                if (radioButtonTransport0.Checked != false)
                {
                    textBoxURL.Text += "&Transport=0";
                }
                else if (radioButtonTransport1.Checked != false)
                {
                    textBoxURL.Text += "&Transport=1";
                }
                else
                {
                    textBoxURL.Text += "&Transport=2";
                }
            }
            else
            {
                // 旅客以外
                if (radioButtonUseHighway0.Checked != false)
                {
                    textBoxURL.Text += "&UseHighway=0";
                }
                else
                {
                    textBoxURL.Text += "&UseHighway=1";
                }
            }

            if (radioButtonOptimize0.Checked != false)
            {
                textBoxURL.Text += "&Optimize=0";
            }
            else
            {
                textBoxURL.Text += "&Optimize=1";

                // 最短巡回順計算の際の発着地固定
                if (radioButtonFixed0.Checked != false)
                {
                    textBoxURL.Text += "&Fixed=0";
                }
                else if (radioButtonFixed1.Checked != false)
                {
                    textBoxURL.Text += "&Fixed=1";
                }
                else if (radioButtonFixed2.Checked != false)
                {
                    textBoxURL.Text += "&Fixed=2";
                }
                else if (radioButtonFixed3.Checked != false)
                {
                    textBoxURL.Text += "&Fixed=3";
                }
            }


            // 住所検索時にエラーとする閾値
            if (radioButtonAddressThreshold1.Checked != false)
            {
                textBoxURL.Text += "&AddressThreshold=1";
            }
            else if (radioButtonAddressThreshold2.Checked != false)
            {
                textBoxURL.Text += "&AddressThreshold=2";
            }
            else if (radioButtonAddressThreshold8.Checked != false)
            {
                textBoxURL.Text += "&AddressThreshold=8";
            }
            else if (radioButtonAddressThreshold16.Checked != false)
            {
                textBoxURL.Text += "&AddressThreshold=16";
            }

            // 通行料金
            if (radioButtonToll0.Checked != false)
            {
                textBoxURL.Text += "&Toll=0";
            }
            else
            {
                textBoxURL.Text += "&Toll=1";
            }

            // ルート
            if (radioButtonPolyline0.Checked != false)
            {
                textBoxURL.Text += "&Polyline=0";
            }
            else
            {
                textBoxURL.Text += "&Polyline=1";
            }

            // 測地系
            if (radioButtonDatum0.Checked != false)
            {
                textBoxURL.Text += "&Datum=0";
            }
            else
            {
                textBoxURL.Text += "&Datum=1";
            }

        
        }

        private void linkLabelACT_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.co.jp");
        }

        private void linkLabelNWID_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.jp/dl/doc/NWIDrule.pdf");
        }

    }
}
